==> nui_core-0.0.85.tar.gz: lib/ui/component/listview/nui_list_models.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/ui/component/listview/nui_listview_bloc.dart';

import 'nui_listview_functions.dart';

typedef UpdateListMap = void Function(Map<String, dynamic> map);
typedef NUIStaggeredHeightToWidthRatio = double Function(dynamic data, int position);

class NUIListItemInstance{
  NUIListActionController getController(){}
}

class PaginationLoad{}
class SwipeRefresh{}

class NUIListItem<T>{
  NUIListItem({@required this.entityClass, @required this.inflater, this.shadowRadius, this.heightToWidthRatio});
  Type entityClass;
  ListItemInflater inflater;
  double shadowRadius;
  NUIStaggeredHeightToWidthRatio heightToWidthRatio; //For staggered list
}

class NUIListItemModel{
  NUIListItemModel(this.position, this.data, {this.checkedMap, this.configMap});
  int position;
  dynamic data;
  Map<String, dynamic> checkedMap;
  Map<String, dynamic> configMap;
}

class NUIListViewModel<T, C>{
  NUIListViewModel({this.skeletalLoading:false, this.paginationLoading:false, this.newData, this.reachedEnd: false, this.swipeRefreshing:false, this.success:false, this.data, this.appending: false, this.message, this.errorCode, this.cursor, this.updateCheckedMap, this.updateConfigMap});
  bool paginationLoading;
  bool skeletalLoading;
  bool swipeRefreshing;
  final List<T> data;
  final List<T> newData;
  final String message;
  final bool success;
  final String errorCode;
  final C cursor;
  final bool appending;
  final bool reachedEnd;
  final UpdateListMap updateCheckedMap;
  final UpdateListMap updateConfigMap;

  bool isLoading(){
    return paginationLoading || skeletalLoading || swipeRefreshing;
  }
}

==> nui_core-0.0.127.tar.gz: lib/ui/component/listview/nui_list_models.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/ui/component/listview/nui_listview_bloc.dart';

import 'nui_listview_functions.dart';

typedef UpdateListMap = void Function(Map<String, dynamic> map);
typedef NUIListItemIdCallback = String Function(dynamic data);
typedef NUIStaggeredHeightToWidthRatio = double Function(dynamic data, int position);

class NUIListItemInstance{
  NUIListActionController getController(){}
}

class PaginationLoad{}
class SwipeRefresh{}

class NUIListItem<T>{
  NUIListItem({@required this.entityClass, @required this.inflater, this.shadowRadius, this.heightToWidthRatio, this.dataId});
  Type entityClass;
  ListItemInflater inflater;
  double shadowRadius;
  NUIListItemIdCallback dataId;
  NUIStaggeredHeightToWidthRatio heightToWidthRatio; //For staggered list
}

class NUIListItemModel{
  NUIListItemModel(this.position, this.data, {this.checkedMap, this.configMap});
  int position;
  dynamic data;
  Map<String, dynamic> checkedMap;
  Map<String, dynamic> configMap;
}

class NUIListViewModel<T, C>{
  NUIListViewModel({this.skeletalLoading:false, this.paginationLoading:false, this.newData, this.reachedEnd: false, this.swipeRefreshing:false, this.success:false, this.data, this.appending: false, this.message, this.errorCode, this.cursor, this.updateCheckedMap, this.updateConfigMap});
  bool paginationLoading;
  bool skeletalLoading;
  bool swipeRefreshing;
  final List<T> data;
  final List<T> newData;
  final String message;
  final bool success;
  final String errorCode;
  final C cursor;
  final bool appending;
  final bool reachedEnd;
  final UpdateListMap updateCheckedMap;
  final UpdateListMap updateConfigMap;

  bool isLoading(){
    return paginationLoading || skeletalLoading || swipeRefreshing;
  }
}
